==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesFeaturesRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesFeaturesRuleArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.FeaturesPolicy
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property requiredFeaturesPolicy
 */
public data class ResourceTypeRegistrationPropertiesFeaturesRuleArgs(
    public val requiredFeaturesPolicy: Output<Either<String, FeaturesPolicy>>,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesFeaturesRuleArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesFeaturesRuleArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesFeaturesRuleArgs.builder()
            .requiredFeaturesPolicy(
                requiredFeaturesPolicy.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesFeaturesRuleArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesFeaturesRuleArgsBuilder internal constructor() {
    private var requiredFeaturesPolicy: Output<Either<String, FeaturesPolicy>>? = null

    /**
     * @param value
     */
    @JvmName("xlnlgwfepogjight")
    public suspend fun requiredFeaturesPolicy(`value`: Output<Either<String, FeaturesPolicy>>) {
        this.requiredFeaturesPolicy = value
    }

    /**
     * @param value
     */
    @JvmName("gbbomhdktybskysi")
    public suspend fun requiredFeaturesPolicy(`value`: Either<String, FeaturesPolicy>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requiredFeaturesPolicy = mapped
    }

    /**
     * @param value
     */
    @JvmName("fwyrbjwihumbqull")
    public fun requiredFeaturesPolicy(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FeaturesPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requiredFeaturesPolicy = mapped
    }

    /**
     * @param value
     */
    @JvmName("kegpvhuxbroxqeqa")
    public fun requiredFeaturesPolicy(`value`: FeaturesPolicy) {
        val toBeMapped = Either.ofRight<String, FeaturesPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requiredFeaturesPolicy = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesFeaturesRuleArgs =
        ResourceTypeRegistrationPropertiesFeaturesRuleArgs(
            requiredFeaturesPolicy = requiredFeaturesPolicy ?: throw
                PulumiNullFieldException("requiredFeaturesPolicy"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesFeaturesRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesFeaturesRuleArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.FeaturesPolicy
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property requiredFeaturesPolicy
 */
public data class ResourceTypeRegistrationPropertiesFeaturesRuleArgs(
    public val requiredFeaturesPolicy: Output<Either<String, FeaturesPolicy>>,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesFeaturesRuleArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesFeaturesRuleArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesFeaturesRuleArgs.builder()
            .requiredFeaturesPolicy(
                requiredFeaturesPolicy.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesFeaturesRuleArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesFeaturesRuleArgsBuilder internal constructor() {
    private var requiredFeaturesPolicy: Output<Either<String, FeaturesPolicy>>? = null

    /**
     * @param value
     */
    @JvmName("xmrlfmonsoiddhck")
    public suspend fun requiredFeaturesPolicy(`value`: Output<Either<String, FeaturesPolicy>>) {
        this.requiredFeaturesPolicy = value
    }

    /**
     * @param value
     */
    @JvmName("bfkewgdwljjjukod")
    public suspend fun requiredFeaturesPolicy(`value`: Either<String, FeaturesPolicy>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requiredFeaturesPolicy = mapped
    }

    /**
     * @param value
     */
    @JvmName("crsojrfkvjinfqqe")
    public fun requiredFeaturesPolicy(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FeaturesPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requiredFeaturesPolicy = mapped
    }

    /**
     * @param value
     */
    @JvmName("cnolbsghdtciyfnl")
    public fun requiredFeaturesPolicy(`value`: FeaturesPolicy) {
        val toBeMapped = Either.ofRight<String, FeaturesPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requiredFeaturesPolicy = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesFeaturesRuleArgs =
        ResourceTypeRegistrationPropertiesFeaturesRuleArgs(
            requiredFeaturesPolicy = requiredFeaturesPolicy ?: throw
                PulumiNullFieldException("requiredFeaturesPolicy"),
        )
}
